require 'her'
require 'request_store'

require "verse/controller"
require "initializers/engine" if defined?(Rails)

require "verse/version"

require "verse/configuration"

require 'helpers/user_authentication'

module Verse
  class << self
    attr_writer :configuration

    def user_token
      RequestStore.store[:user_token]
    end

    def user_token=(user_token)
      RequestStore.store[:user_token] = user_token
    end
  end

  def self.configuration
    @configuration ||= Configuration.new
  end

  def self.configure
    yield(configuration)

    api =
      Her::API.setup url: configuration.url,
                     headers: {
                       'App-Token' => configuration.app_token
                     } do |c|
        # Request
        c.use Verse::UserAuthentication
        c.use Faraday::Request::UrlEncoded

        # Response
        c.use Her::Middleware::SecondLevelParseJSON

        # Adapter
        c.use Faraday::Adapter::NetHttp
      end

    require 'verse/models'
    api
  end
end
